Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(917)

Unified Diff: net/ssl/ssl_client_auth_cache_unittest.cc

Issue 2363653002: Cleanup unreachable cert adding code (Closed)
Patch Set: Rebased Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ssl/ssl_client_auth_cache.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ssl/ssl_client_auth_cache_unittest.cc
diff --git a/net/ssl/ssl_client_auth_cache_unittest.cc b/net/ssl/ssl_client_auth_cache_unittest.cc
index 20b0eed50e2d6c775e356801205e9bc7340116fc..d934f5c93cada20932228b373eeb612cf31c4c94 100644
--- a/net/ssl/ssl_client_auth_cache_unittest.cc
+++ b/net/ssl/ssl_client_auth_cache_unittest.cc
@@ -170,8 +170,8 @@ TEST(SSLClientAuthCacheTest, LookupNullPreference) {
EXPECT_EQ(nullptr, cached_cert.get());
}
-// Check that the OnCertAdded() method removes all cache entries.
-TEST(SSLClientAuthCacheTest, OnCertAdded) {
+// Check that the OnCertDBChanged() method removes all cache entries.
+TEST(SSLClientAuthCacheTest, OnCertDBChanged) {
SSLClientAuthCache cache;
HostPortPair server1("foo", 443);
@@ -194,7 +194,7 @@ TEST(SSLClientAuthCacheTest, OnCertAdded) {
EXPECT_TRUE(cache.Lookup(server2, &cached_cert, &cached_pkey));
EXPECT_EQ(nullptr, cached_cert.get());
- cache.OnCertAdded(nullptr);
+ cache.OnCertDBChanged(nullptr);
// Check that we no longer have entries for either server.
EXPECT_FALSE(cache.Lookup(server1, &cached_cert, &cached_pkey));
« no previous file with comments | « net/ssl/ssl_client_auth_cache.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698